@@ -8,14 +8,16 @@ from stlearn._compat import Literal
 from typing import Optional, Union
 from anndata import AnnData
 import warnings
-#from .utils import get_img_from_fig, checkType
+
+# from .utils import get_img_from_fig, checkType
 import scanpy
 
+
 def non_spatial_plot(
     adata: AnnData,
     use_label: str = "louvain",
 ) -> Optional[AnnData]:
-    
+
     """\
     A wrap function to plot all the non-spatial plot from scanpy.
 
@@ -35,22 +37,20 @@ def non_spatial_plot(
     Nothing
     """
 
-    #plt.rcParams['figure.dpi'] = dpi
+    # plt.rcParams['figure.dpi'] = dpi
 
-    if 'paga' in adata.uns.keys():
-        adata.uns[use_label+"_colors"] = adata.uns["tmp_color"]
+    if "paga" in adata.uns.keys():
+        # adata.uns[use_label+"_colors"] = adata.uns["tmp_color"]
 
         print("PAGA plot:")
 
         scanpy.pl.paga(adata, color=use_label)
 
-
-        scanpy.tl.draw_graph(adata, init_pos='paga')
-        adata.uns[use_label+"_colors"] = adata.uns["tmp_color"]
-
+        scanpy.tl.draw_graph(adata, init_pos="paga")
+        # adata.uns[use_label+"_colors"] = adata.uns["tmp_color"]
 
         print("Gene expression (reduced dimension) plot:")
-        scanpy.pl.draw_graph(adata, color=use_label, legend_loc='on data')
+        scanpy.pl.draw_graph(adata, color=use_label, legend_loc="on data")
 
         print("Diffusion pseudotime plot:")
         scanpy.pl.draw_graph(adata, color="dpt_pseudotime")
@@ -58,6 +58,6 @@ def non_spatial_plot(
     else:
 
         scanpy.pl.draw_graph(adata)
-        adata.uns[use_label+"_colors"] = adata.uns["tmp_color"]
+        # adata.uns[use_label+"_colors"] = adata.uns["tmp_color"]
 
-        scanpy.pl.draw_graph(adata, color=use_label, legend_loc='on data')
+        scanpy.pl.draw_graph(adata, color=use_label, legend_loc="on data")
