@@ -5,6 +5,7 @@ import pandas as pd
 import networkx as nx
 from scipy.spatial.distance import cdist
 
+
 def global_level(
     adata: AnnData,
     use_label: str = "louvain",
@@ -37,8 +38,6 @@ def global_level(
     Anndata
     """
 
-    
-
     assert w <= 1, "w should be in range 0 to 1"
     # Get global graph
     G = adata.uns["global_graph"]
@@ -47,17 +46,22 @@ def global_level(
 
     # Query cluster
     query_nodes = list_cluster
-    query_nodes = ordering_nodes(query_nodes, use_label,adata)
+    query_nodes = ordering_nodes(query_nodes, use_label, adata)
 
     if verbose:
-        print("Start to construct the trajectory: " +  " -> ".join(np.array(query_nodes).astype(str)))
+        print(
+            "Start to construct the trajectory: "
+            + " -> ".join(np.array(query_nodes).astype(str))
+        )
 
     query_dict = {}
     order_dict = {}
 
     for i in query_nodes:
         order = 0
-        for j in adata.obs[adata.obs[use_label] == str(i)]["sub_cluster_labels"].unique():
+        for j in adata.obs[adata.obs[use_label] == str(i)][
+            "sub_cluster_labels"
+        ].unique():
             query_dict[int(j)] = int(i)
             order_dict[int(j)] = int(order)
 
@@ -69,18 +73,24 @@ def global_level(
     edge_list = []
     for i, j in enumerate(query_nodes):
         order_big_dict[j] = int(i)
-        if i == len(query_nodes)-1:
+        if i == len(query_nodes) - 1:
             break
         for j in adata.uns["split_node"][query_nodes[i]]:
-            for k in adata.uns["split_node"][query_nodes[i+1]]:
+            for k in adata.uns["split_node"][query_nodes[i + 1]]:
                 edge_list.append((int(j), int(k)))
 
         # Calculate DPT distance matrix
-        dm_list.append(dpt_distance_matrix(
-            adata, query_nodes[i], query_nodes[i+1], use_label=use_label))
+        dm_list.append(
+            dpt_distance_matrix(
+                adata, query_nodes[i], query_nodes[i + 1], use_label=use_label
+            )
+        )
         # Calculate Spatial distance matrix
-        sdm_list.append(spatial_distance_matrix(
-            adata, query_nodes[i], query_nodes[i+1], use_label=use_label))
+        sdm_list.append(
+            spatial_distance_matrix(
+                adata, query_nodes[i], query_nodes[i + 1], use_label=use_label
+            )
+        )
 
     # Get centroid dictionary
     centroid_dict = adata.uns["centroid_dict"]
@@ -93,28 +103,31 @@ def global_level(
         prepare_root.append(centroid_dict[int(node)])
 
     prepare_root = np.array(prepare_root)
-    centroide = (sum(prepare_root[:, 0])/len(prepare_root[:, 0]),
-                 sum(prepare_root[:, 1])/len(prepare_root[:, 1]))
+    centroide = (
+        sum(prepare_root[:, 0]) / len(prepare_root[:, 0]),
+        sum(prepare_root[:, 1]) / len(prepare_root[:, 1]),
+    )
     centroid_dict[9999] = centroide
 
-    labels = nx.get_edge_attributes(H_sub, 'weight')
+    labels = nx.get_edge_attributes(H_sub, "weight")
 
     for edge, _ in labels.items():
 
         dm = dm_list[order_big_dict[query_dict[edge[0]]]]
         sdm = sdm_list[order_big_dict[query_dict[edge[0]]]]
 
-        weight = dm[order_dict[edge[0]], order_dict[edge[1]]] * \
-            w + sdm[order_dict[edge[0]], order_dict[edge[1]]]*(1-w)
-        H_sub[edge[0]][edge[1]]['weight'] = weight
-    #tmp = H_sub 
+        weight = dm[order_dict[edge[0]], order_dict[edge[1]]] * w + sdm[
+            order_dict[edge[0]], order_dict[edge[1]]
+        ] * (1 - w)
+        H_sub[edge[0]][edge[1]]["weight"] = weight
+    # tmp = H_sub
     H_sub = nx.algorithms.tree.minimum_spanning_arborescence(H_sub)
-    #remove = [edge for edge in H_sub.edges if 9999 in edge]
+    # remove = [edge for edge in H_sub.edges if 9999 in edge]
     # H_sub.remove_edges_from(remove)
     # remove.remove_node(9999)
 
     adata.uns["PTS_graph"] = H_sub
-    
+
     if return_graph:
         return H_sub
 
@@ -123,6 +136,7 @@ def global_level(
 ## Global level PTS ##
 ########################
 
+
 def get_node(node_list, split_node):
     result = np.array([])
     for node in node_list:
@@ -130,11 +144,12 @@ def get_node(node_list, split_node):
     return result.astype(int)
 
 
-def ordering_nodes(node_list,use_label, adata):
+def ordering_nodes(node_list, use_label, adata):
     mean_dpt = []
     for node in node_list:
-        mean_dpt.append(adata.obs[adata.obs[use_label]
-                                  == str(node)]["dpt_pseudotime"].min())
+        mean_dpt.append(
+            adata.obs[adata.obs[use_label] == str(node)]["dpt_pseudotime"].min()
+        )
 
     return list(np.array(node_list)[np.argsort(mean_dpt)])
 
@@ -149,20 +164,29 @@ def dpt_distance_matrix(adata, cluster1, cluster2, use_label):
     chosen_sub1 = chosen_adata1.obs["sub_cluster_labels"].unique()
     for i in range(0, len(chosen_sub1)):
         sub_dpt1.append(
-            chosen_adata1.obs[chosen_adata1.obs["sub_cluster_labels"] == chosen_sub1[i]]["dpt_pseudotime"].max())
+            chosen_adata1.obs[
+                chosen_adata1.obs["sub_cluster_labels"] == chosen_sub1[i]
+            ]["dpt_pseudotime"].max()
+        )
 
     sub_dpt2 = []
     chosen_sub2 = chosen_adata2.obs["sub_cluster_labels"].unique()
     for i in range(0, len(chosen_sub2)):
         sub_dpt2.append(
-            chosen_adata2.obs[chosen_adata2.obs["sub_cluster_labels"] == chosen_sub2[i]]["dpt_pseudotime"].max())
+            chosen_adata2.obs[
+                chosen_adata2.obs["sub_cluster_labels"] == chosen_sub2[i]
+            ]["dpt_pseudotime"].max()
+        )
 
-    dm = cdist(np.array(sub_dpt1).reshape(-1, 1),
-               np.array(sub_dpt2).reshape(-1, 1), lambda u, v: v-u)
-    #from sklearn.preprocessing import MinMaxScaler
-    #scaler = MinMaxScaler()
-    #scale_dm = scaler.fit_transform(dm)
-    scale_dm = (dm+(-np.min(dm)))/np.max(dm)
+    dm = cdist(
+        np.array(sub_dpt1).reshape(-1, 1),
+        np.array(sub_dpt2).reshape(-1, 1),
+        lambda u, v: v - u,
+    )
+    # from sklearn.preprocessing import MinMaxScaler
+    # scaler = MinMaxScaler()
+    # scale_dm = scaler.fit_transform(dm)
+    scale_dm = (dm + (-np.min(dm))) / np.max(dm)
     return scale_dm
 
 
@@ -187,9 +211,9 @@ def spatial_distance_matrix(adata, cluster1, cluster2, use_label):
 
     sdm = cdist(np.array(sub_coord1), np.array(sub_coord2), "euclidean")
 
-    #from sklearn.preprocessing import MinMaxScaler
-    #scaler = MinMaxScaler()
-    #scale_sdm = scaler.fit_transform(sdm)
-    scale_sdm = sdm/np.max(sdm)
+    # from sklearn.preprocessing import MinMaxScaler
+    # scaler = MinMaxScaler()
+    # scale_sdm = scaler.fit_transform(sdm)
+    scale_sdm = sdm / np.max(sdm)
 
     return scale_sdm
