@@ -50,22 +50,32 @@ def local_level(
     sd = []
     centroid_dict = cluster_data.uns["centroid_dict"]
     for i in list_cluster:
-        if len(adata.obs[adata.obs["sub_cluster_labels"] == str(i)]) > adata.uns["threshold_spots"]:
+        if (
+            len(adata.obs[adata.obs["sub_cluster_labels"] == str(i)])
+            > adata.uns["threshold_spots"]
+        ):
             dpt.append(
-                cluster_data.obs[cluster_data.obs["sub_cluster_labels"] == i]["dpt_pseudotime"].max())
+                cluster_data.obs[cluster_data.obs["sub_cluster_labels"] == i][
+                    "dpt_pseudotime"
+                ].max()
+            )
             sd.append(centroid_dict[int(i)])
-    dm = cdist(np.array(dpt).reshape(-1, 1),
-               np.array(dpt).reshape(-1, 1), lambda u, v: np.abs(u-v))
+    dm = cdist(
+        np.array(dpt).reshape(-1, 1),
+        np.array(dpt).reshape(-1, 1),
+        lambda u, v: np.abs(u - v),
+    )
 
-    non_abs_dm = cdist(np.array(dpt).reshape(-1, 1),
-                       np.array(dpt).reshape(-1, 1), lambda u, v: u-v)
+    non_abs_dm = cdist(
+        np.array(dpt).reshape(-1, 1), np.array(dpt).reshape(-1, 1), lambda u, v: u - v
+    )
     adata.uns["nonabs_dpt_distance_matrix"] = non_abs_dm
 
-    scale_dm = dm/np.max(dm)
+    scale_dm = dm / np.max(dm)
     sdm = cdist(np.array(sd), np.array(sd), "euclidean")
-    scale_sdm = sdm/np.max(sdm)
+    scale_sdm = sdm / np.max(sdm)
 
-    stdm = scale_dm*w + scale_sdm*(1-w)
+    stdm = scale_dm * w + scale_sdm * (1 - w)
     adata.uns["ST_distance_matrix"] = stdm
 
     if return_matrix:
