@@ -7,18 +7,21 @@ import numpy as np
 from PIL import Image
 import pandas as pd
 import stlearn
+from .._compat import Literal
 import scanpy
 import scipy
 
+_QUALITY = Literal["fulres", "hires", "lowres"]
+
 def Read10X(
     path: Union[str, Path],
     genome: Optional[str] = None,
     count_file: str = "filtered_feature_bc_matrix.h5",
     library_id: str = None,
     load_images: Optional[bool] = True,
-    quality: str = "hires"
-    ) -> AnnData:
-    
+    quality: _QUALITY = "hires",
+) -> AnnData:
+
     """\
     Read Visium data from 10X (wrap read_visium from scanpy)
 
@@ -63,7 +66,7 @@ def Read10X(
     :attr:`~anndata.AnnData.uns`\\ `['spatial']`
         Dict of spaceranger output files with 'library_id' as key
     :attr:`~anndata.AnnData.uns`\\ `['spatial'][library_id]['images']`
-        Dict of images (`'hires'` and `'lowres'`)
+        Dict of images (`'fulres'`, `'hires'` and `'lowres'`)
     :attr:`~anndata.AnnData.uns`\\ `['spatial'][library_id]['scalefactors']`
         Scale factors for the spots
     :attr:`~anndata.AnnData.uns`\\ `['spatial'][library_id]['metadata']`
@@ -71,25 +74,28 @@ def Read10X(
     :attr:`~anndata.AnnData.obsm`\\ `['spatial']`
         Spatial spot coordinates, usable as `basis` by :func:`~scanpy.pl.embedding`.
     """
-    
+
     from scanpy import read_visium
-    adata = read_visium(path, genome=None,
-     count_file=count_file,
-      library_id=None,
-       load_images=True)
+
+    adata = read_visium(path, genome=genome,
+                        count_file=count_file,
+                        library_id=library_id,
+                        load_images=load_images)
     adata.var_names_make_unique()
 
     adata.obs['sum_counts'] = np.array(adata.X.sum(axis=1))
 
-    
     if library_id is None:
         library_id = list(adata.uns["spatial"].keys())[0]
-        
-    scale = adata.uns["spatial"][library_id]["scalefactors"]["tissue_"+quality+"_scalef"]
-    image_coor = adata.obsm["spatial"]*scale
 
-    adata.obs["imagecol"] = image_coor[:,0]
-    adata.obs["imagerow"] = image_coor[:,1]
+    if quality == "fulres":
+        image_coor = adata.obsm["spatial"]
+    else:
+        scale = adata.uns["spatial"][library_id]["scalefactors"]["tissue_" + quality + "_scalef"]
+        image_coor = adata.obsm["spatial"] * scale
+
+    adata.obs["imagecol"] = image_coor[:, 0]
+    adata.obs["imagerow"] = image_coor[:, 1]
     adata.uns["spatial"]["use_quality"] = quality
 
     return adata
@@ -101,8 +107,8 @@ def ReadOldST(
     image_file: Union[str, Path] = None,
     library_id: str = "OldST",
     scale: float = 1.0,
-    quality: str = "hires"
-    ) -> AnnData:
+    quality: str = "hires",
+) -> AnnData:
 
     """\
     Read Old Spatial Transcriptomics data
@@ -127,11 +133,12 @@ def ReadOldST(
     """
 
     adata = stlearn.read.file_table(count_matrix_file)
-    adata=stlearn.add.parsing(adata,
-        coordinates_file = spatial_file)
-    stlearn.add.image(adata, library_id=library_id, quality=quality,imgpath=image_file, scale=scale)
+    adata = stlearn.add.parsing(adata, coordinates_file=spatial_file)
+    stlearn.add.image(
+        adata, library_id=library_id, quality=quality, imgpath=image_file, scale=scale
+    )
 
-    adata.obs['sum_counts'] = np.array(adata.X.sum(axis=1))
+    adata.obs["sum_counts"] = np.array(adata.X.sum(axis=1))
 
     return adata
 
@@ -141,8 +148,8 @@ def ReadSlideSeq(
     spatial_file: Union[str, Path],
     library_id: str = None,
     scale: float = 1.0,
-    quality: str = "hires"
-    ) -> AnnData:
+    quality: str = "hires",
+) -> AnnData:
 
     """\
     Read Slide-seq data
@@ -167,20 +174,20 @@ def ReadSlideSeq(
     count = pd.read_csv(count_matrix_file)
     meta = pd.read_csv(spatial_file)
 
-    adata = AnnData(count.iloc[:,1:].set_index("gene").T)
+    adata = AnnData(count.iloc[:, 1:].set_index("gene").T)
 
     adata.var["ENSEMBL"] = count["ENSEMBL"].values
 
     adata.obs["index"] = meta["index"].values
-    
-    adata.obs["imagecol"] = meta["x"].values*scale
-    adata.obs["imagerow"] = meta["y"].values*scale
+
+    adata.obs["imagecol"] = meta["x"].values * scale
+    adata.obs["imagerow"] = meta["y"].values * scale
 
     # Create image
-    max_size = np.max([adata.obs["imagecol"].max(),adata.obs["imagerow"].max()])
-    max_size = int(max_size + 0.1*max_size)
+    max_size = np.max([adata.obs["imagecol"].max(), adata.obs["imagerow"].max()])
+    max_size = int(max_size + 0.1 * max_size)
 
-    image = Image.new('RGB', (max_size, max_size), (0, 0, 0))
+    image = Image.new("RGB", (max_size, max_size), (0, 0, 0))
     imgarr = np.array(image)
 
     if library_id is None:
@@ -192,21 +199,23 @@ def ReadSlideSeq(
     adata.uns["spatial"][library_id]["images"][quality] = imgarr
     adata.uns["spatial"]["use_quality"] = quality
     adata.uns["spatial"][library_id]["scalefactors"] = {}
-    adata.uns["spatial"][library_id]["scalefactors"]["tissue_" + quality + "_scalef"] = scale
-    adata.obsm["spatial"] = meta[["x","y"]].values
+    adata.uns["spatial"][library_id]["scalefactors"][
+        "tissue_" + quality + "_scalef"
+    ] = scale
+    adata.obsm["spatial"] = meta[["x", "y"]].values
 
-    adata.obs['sum_counts'] = np.array(adata.X.sum(axis=1))
-    
+    adata.obs["sum_counts"] = np.array(adata.X.sum(axis=1))
 
     return adata
 
+
 def ReadMERFISH(
     count_matrix_file: Union[str, Path],
     spatial_file: Union[str, Path],
     library_id: str = None,
     scale: float = 1,
-    quality: str = "hires"
-    ) -> AnnData:
+    quality: str = "hires",
+) -> AnnData:
 
     """\
     Read MERFISH data
@@ -230,22 +239,24 @@ def ReadMERFISH(
 
     coordinates = pd.read_excel(spatial_file, index_col=0)
     if coordinates.min().min() < 0:
-        coordinates = coordinates + np.abs(coordinates.min().min())+100
+        coordinates = coordinates + np.abs(coordinates.min().min()) + 100
     from scanpy import read_csv
+
     counts = read_csv(count_matrix_file).transpose()
 
     adata_merfish = counts[coordinates.index, :]
     adata_merfish.obsm["spatial"] = coordinates.to_numpy()
-    adata_merfish.obs["imagecol"] = adata_merfish.obsm["spatial"][:,0]
-    adata_merfish.obs["imagerow"] = adata_merfish.obsm["spatial"][:,1]
+    adata_merfish.obs["imagecol"] = adata_merfish.obsm["spatial"][:, 0]
+    adata_merfish.obs["imagerow"] = adata_merfish.obsm["spatial"][:, 1]
 
     # Create image
-    max_size = np.max([adata_merfish.obs["imagecol"].max(),adata_merfish.obs["imagerow"].max()])
-    max_size = int(max_size + 0.1*max_size)
-    image = Image.new('RGB', (max_size, max_size), (255, 255, 255))
+    max_size = np.max(
+        [adata_merfish.obs["imagecol"].max(), adata_merfish.obs["imagerow"].max()]
+    )
+    max_size = int(max_size + 0.1 * max_size)
+    image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
     imgarr = np.array(image)
 
-
     if library_id is None:
         library_id = "MERSEQ"
 
@@ -255,23 +266,26 @@ def ReadMERFISH(
     adata_merfish.uns["spatial"][library_id]["images"][quality] = imgarr
     adata_merfish.uns["spatial"]["use_quality"] = quality
     adata_merfish.uns["spatial"][library_id]["scalefactors"] = {}
-    adata_merfish.uns["spatial"][library_id]["scalefactors"]["tissue_"+quality+"_scalef"] = scale
+    adata_merfish.uns["spatial"][library_id]["scalefactors"][
+        "tissue_" + quality + "_scalef"
+    ] = scale
 
-    adata_merfish.obs["imagecol"] = adata_merfish.obsm["spatial"][:,0]*scale
-    adata_merfish.obs["imagerow"] = adata_merfish.obsm["spatial"][:,1]*scale
+    adata_merfish.obs["imagecol"] = adata_merfish.obsm["spatial"][:, 0] * scale
+    adata_merfish.obs["imagerow"] = adata_merfish.obsm["spatial"][:, 1] * scale
 
-    adata_merfish.obs['sum_counts'] = np.array(adata_merfish.X.sum(axis=1))
+    adata_merfish.obs["sum_counts"] = np.array(adata_merfish.X.sum(axis=1))
 
     return adata_merfish
 
+
 def ReadSeqFish(
     count_matrix_file: Union[str, Path],
     spatial_file: Union[str, Path],
     library_id: str = None,
     scale: float = 1.0,
     quality: str = "hires",
-    field: int = 0
-    ) -> AnnData:
+    field: int = 0,
+) -> AnnData:
 
     """\
     Read SeqFish data
@@ -295,26 +309,26 @@ def ReadSeqFish(
     AnnData
     """
 
-    count = pd.read_table(count_matrix_file,header=None)
-    spatial = pd.read_table(spatial_file,index_col=False)
-    
+    count = pd.read_table(count_matrix_file, header=None)
+    spatial = pd.read_table(spatial_file, index_col=False)
+
     count = count.T
     count.columns = count.iloc[0]
     count = count.drop(count.index[0]).reset_index(drop=True)
-    count = count[count["Field_of_View"] == field].drop(count.columns[[0,1]],axis=1)
-    
+    count = count[count["Field_of_View"] == field].drop(count.columns[[0, 1]], axis=1)
+
     spatial = spatial[spatial["Field_of_View"] == field]
-    
+
     adata = AnnData(count)
-    
-    adata.obs["imagecol"] = spatial["X"].values*scale
-    adata.obs["imagerow"] = spatial["Y"].values*scale
+
+    adata.obs["imagecol"] = spatial["X"].values * scale
+    adata.obs["imagerow"] = spatial["Y"].values * scale
 
     # Create image
-    max_size = np.max([adata.obs["imagecol"].max(),adata.obs["imagerow"].max()])
-    max_size = int(max_size + 0.1*max_size)
+    max_size = np.max([adata.obs["imagecol"].max(), adata.obs["imagerow"].max()])
+    max_size = int(max_size + 0.1 * max_size)
 
-    image = Image.new('RGB', (max_size, max_size), (255, 255, 255))
+    image = Image.new("RGB", (max_size, max_size), (255, 255, 255))
     imgarr = np.array(image)
 
     if library_id is None:
@@ -326,10 +340,11 @@ def ReadSeqFish(
     adata.uns["spatial"][library_id]["images"][quality] = imgarr
     adata.uns["spatial"]["use_quality"] = quality
     adata.uns["spatial"][library_id]["scalefactors"] = {}
-    adata.uns["spatial"][library_id]["scalefactors"]["tissue_" + quality + "_scalef"] = scale
-    adata.obsm["spatial"] = spatial[["X","Y"]].values
+    adata.uns["spatial"][library_id]["scalefactors"][
+        "tissue_" + quality + "_scalef"
+    ] = scale
+    adata.obsm["spatial"] = spatial[["X", "Y"]].values
 
-    adata.obs['sum_counts'] = np.array(adata.X.sum(axis=1))
-    
+    adata.obs["sum_counts"] = np.array(adata.X.sum(axis=1))
 
-    return adata
\ No newline at end of file
+    return adata
